CreditNoteItem class

Constructors

CreditNoteItem({String? orderId, String? orderNumber, String? totalItem, String? subTotal, String? discount, String? grandTotal, StatusData? status, String? remarks, CreatedAtDateTime? createdAtDateTime, String? modifyBtnShow, String? placeByType, String? cnType})
CreditNoteItem.fromJson(dynamic json)

Properties

cnType String?
no setter
createdAtDateTime CreatedAtDateTime?
no setter
discount String?
no setter
grandTotal String?
no setter
hashCode int
The hash code for this object.
no setterinherited
modifyBtnShow String?
no setter
orderId String?
no setter
orderNumber String?
no setter
placeByType String?
no setter
remarks String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status StatusData?
no setter
subTotal String?
no setter
totalItem String?
no setter

Methods

copyWith({String? orderId, String? orderNumber, String? totalItem, String? subTotal, String? discount, String? grandTotal, StatusData? status, String? remarks, CreatedAtDateTime? createdAtDateTime, String? modifyBtnShow, String? placeByType, String? cnType}) CreditNoteItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited