LoginData class

Constructors

LoginData({String? userId, String? token, String? parentId, String? companyId, String? masterUserId, String? userType, String? name, String? nameSmall, String? nameSmall2, String? emailAddress, String? countryCode, String? contactNo, String? area, String? pincode, String? websiteUrl, String? companyAddress, String? discountAsPer, String? showQuantityIndicator, String? discountAsPerFixed, String? discoutAsPerProductVise, String? returnMaxDay, String? expiryReturn, String? countryId, String? country, String? stateId, String? state, String? cityId, String? city, String? companyLogoFull, String? drugLicenseNo, String? drugLicensePhoto, String? drugLicensePhotoFull, String? drugLicensePdf, String? drugLicensePdfFull, String? drugLicensePhoto0OrPdf1, String? gstNo, String? gstPhoto, String? gstPhotoFull, String? gstPdf, String? gstPdfFull, String? gstPhoto0OrPdf1, String? panCardNo, String? panCardPhoto, String? panCardPhotoFull, String? panCardPdf, String? panCardPdfFull, String? panCardPhoto0OrPdf1, String? orderGstTypeId, CreatedAtDateTime? createdAtDateTime, UpdatedAtDateTime? updatedAtDateTime, String? isActive, String? address, List<DrugLicenseArray>? drugLicenseArray, List<RetailerIdsArrayMap>? retailerIdsArrayMap})
LoginData.fromJson(dynamic json)

Properties

address String?
no setter
area String?
no setter
city String?
no setter
cityId String?
no setter
companyAddress String?
no setter
companyId String?
no setter
no setter
companyLogoFull String?
no setter
contactNo String?
no setter
country String?
no setter
countryCode String?
no setter
countryId String?
no setter
createdAtDateTime CreatedAtDateTime?
no setter
discountAsPer String?
no setter
discountAsPerFixed String?
no setter
discoutAsPerProductVise String?
no setter
drugLicenseArray List<DrugLicenseArray>?
no setter
drugLicenseNo String?
no setter
drugLicensePdf String?
no setter
drugLicensePdfFull String?
no setter
drugLicensePhoto String?
no setter
drugLicensePhoto0OrPdf1 String?
no setter
drugLicensePhotoFull String?
no setter
emailAddress String?
no setter
expiryReturn String?
no setter
gstNo String?
no setter
gstPdf String?
no setter
gstPdfFull String?
no setter
gstPhoto String?
no setter
gstPhoto0OrPdf1 String?
no setter
gstPhotoFull String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isActive String?
no setter
masterUserId String?
no setter
name String?
no setter
nameSmall String?
no setter
nameSmall2 String?
no setter
orderGstTypeId String?
no setter
panCardNo String?
no setter
panCardPdf String?
no setter
panCardPdfFull String?
no setter
panCardPhoto String?
no setter
panCardPhoto0OrPdf1 String?
no setter
panCardPhotoFull String?
no setter
parentId String?
no setter
pincode String?
no setter
retailerIdsArrayMap List<RetailerIdsArrayMap>?
no setter
returnMaxDay String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showQuantityIndicator String?
no setter
state String?
no setter
stateId String?
no setter
token String?
no setter
updatedAtDateTime UpdatedAtDateTime?
no setter
userId String?
no setter
userType String?
no setter
websiteUrl String?
no setter

Methods

copyWith({String? userId, String? parentId, String? token, String? companyId, String? masterUserId, String? userType, String? name, String? nameSmall, String? nameSmall2, String? emailAddress, String? countryCode, String? contactNo, String? area, String? pincode, String? websiteUrl, String? companyAddress, String? discountAsPer, String? showQuantityIndicator, String? discountAsPerFixed, String? discoutAsPerProductVise, String? returnMaxDay, String? expiryReturn, String? countryId, String? country, String? stateId, String? state, String? cityId, String? city, String? companyLogoFull, String? drugLicenseNo, String? drugLicensePhoto, String? drugLicensePhotoFull, String? drugLicensePdf, String? drugLicensePdfFull, String? drugLicensePhoto0OrPdf1, String? gstNo, String? gstPhoto, String? gstPhotoFull, String? gstPdf, String? gstPdfFull, String? gstPhoto0OrPdf1, String? panCardNo, String? panCardPhoto, String? panCardPhotoFull, String? panCardPdf, String? panCardPdfFull, String? panCardPhoto0OrPdf1, String? orderGstTypeId, CreatedAtDateTime? createdAtDateTime, UpdatedAtDateTime? updatedAtDateTime, String? isActive, String? address, List<DrugLicenseArray>? drugLicenseArray, List<RetailerIdsArrayMap>? retailerIdsArrayMap}) LoginData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited