Address class
address_id : "69" name : "Sevak Medical" contact_no : "91 9887988979" address : "Survey No. - 3763 Plot No. - C Paiki Plot, Front Side, City, First Floor, No. - A, Vasta Devdi Rd, opp. Zenith Mill, Katargam, Surat, Gujarat 395004" country : {"id":"101","name":"India"} state : {"id":"12","name":"Gujarat"} city : {"id":"1041","name":"Surat"}
Constructors
Properties
- address ↔ String?
-
getter/setter pair
- addressId ↔ String?
-
getter/setter pair
- city ↔ City?
-
getter/setter pair
- contactNo ↔ String?
-
getter/setter pair
- country ↔ Country?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ State?
-
getter/setter pair
Methods
-
copyWith(
{String? addressId, String? name, String? contactNo, String? address, Country? country, State? state, City? city}) → Address -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited