ItemsData class

item_id : "322" product_id : "66" brand : "CEFOWELL-200 TAB" company : "Believe Wellness" manufacture : "Believe Wellness" manufacture_sort : "BEL" price : "60.00" mrp : "210.00" price_to_show : {"key":"PTR","value":"60.00"} batch_no : "BN005" quantity : "12" sub_total : "720.00" discount : "10.00" discount_display : "10.00 %" discount_price : "72.00" total_taxable : "648.00" total : "720.00" gst : "18.00" sgst : "0.00" cgst : "0.00" igst : "18.00" sgst_price : "0.00" cgst_price : "0.00" igst_price : "116.64" scheme_min_purchase : "10" scheme_provide : "2" units_per_package : "10" per_unit_quantity : "10" packaging_display : "10 X 10 TABLET" is_free : "0" exp_sort_date : "06/24"

Constructors

ItemsData({String? itemId, String? productId, String? brand, String? company, String? manufacture, String? manufactureSort, String? price, String? mrp, List<PriceToShow>? priceToShow, String? batchNo, String? quantity, String? subTotal, String? discount, String? discountDisplay, String? discountPrice, String? totalTaxable, String? total, String? gst, String? sgst, String? cgst, String? igst, String? sgstPrice, String? cgstPrice, String? igstPrice, String? schemeMinPurchase, String? schemeProvide, String? unitsPerPackage, String? perUnitQuantity, String? packagingDisplay, String? isFree, String? expSortDate, String? extraClaimProduct, String? schemeDiscountPrice, String? schemeDiscount, String? discountAsPerFixedPrice, String? discountAsPerFixed, String? productDiscountPrice, String? productDiscount, String? productDiscountSpecialPrice, String? productDiscountSpecial, String? productDiscountSpecialCompanyPrice, String? productDiscountSpecialCompany})
ItemsData.fromJson(dynamic json)

Properties

batchNo String?
getter/setter pair
brand String?
getter/setter pair
cgst String?
getter/setter pair
cgstPrice String?
getter/setter pair
company String?
getter/setter pair
discount String?
getter/setter pair
discountAsPerFixed String?
getter/setter pair
discountAsPerFixedPrice String?
getter/setter pair
discountDisplay String?
getter/setter pair
discountPrice String?
getter/setter pair
expSortDate String?
getter/setter pair
extraClaimProduct String?
getter/setter pair
gst String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
igst String?
getter/setter pair
igstPrice String?
getter/setter pair
isFree String?
getter/setter pair
itemId String?
getter/setter pair
manufacture String?
getter/setter pair
manufactureSort String?
getter/setter pair
mrp String?
getter/setter pair
packagingDisplay String?
getter/setter pair
perUnitQuantity String?
getter/setter pair
price String?
getter/setter pair
priceToShow List<PriceToShow>?
getter/setter pair
productDiscount String?
getter/setter pair
productDiscountPrice String?
getter/setter pair
productDiscountSpecial String?
getter/setter pair
productDiscountSpecialCompany String?
getter/setter pair
productDiscountSpecialCompanyPrice String?
getter/setter pair
productDiscountSpecialPrice String?
getter/setter pair
productId String?
getter/setter pair
quantity String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemeDiscount String?
getter/setter pair
schemeDiscountPrice String?
getter/setter pair
schemeMinPurchase String?
getter/setter pair
schemeProvide String?
getter/setter pair
sgst String?
getter/setter pair
sgstPrice String?
getter/setter pair
subTotal String?
getter/setter pair
total String?
getter/setter pair
totalTaxable String?
getter/setter pair
unitsPerPackage String?
getter/setter pair

Methods

copyWith({String? itemId, String? productId, String? brand, String? company, String? manufacture, String? manufactureSort, String? price, String? mrp, List<PriceToShow>? priceToShow, String? batchNo, String? quantity, String? subTotal, String? discount, String? discountDisplay, String? discountPrice, String? totalTaxable, String? total, String? gst, String? sgst, String? cgst, String? igst, String? sgstPrice, String? cgstPrice, String? igstPrice, String? schemeMinPurchase, String? schemeProvide, String? unitsPerPackage, String? perUnitQuantity, String? packagingDisplay, String? isFree, String? extraClaimProduct, String? expSortDate, String? schemeDiscountPrice, String? schemeDiscount, String? discountAsPerFixedPrice, String? discountAsPerFixed, String? productDiscountPrice, String? productDiscount, String? productDiscountSpecialPrice, String? productDiscountSpecial, String? productDiscountSpecialCompanyPrice, String? productDiscountSpecialCompany}) ItemsData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited