Master class

company_logo : "logo_1711090106_45.png" company_logo_full : "https://demo1.saptez.com/pharma/api/assets/company/logo/logo_1711090106_45.png"

Constructors

Master({String? companyLogoFull})
Master.fromJson(dynamic json)

Properties

getter/setter pair
companyLogoFull String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? companyLogoFull}) Master
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited