Order class

user_details : {"user_id":"5","name":"Sevak Medical","contact_no":"91 9887988979","email_address":"rajesh@dailydava.com","gst_no":"21YTYTU8787S1Z7","pan_card_no":"YTYTU8787S"} order_id : "151" order_number : "001-001-0000005" sub_total : "720.00" discount : "0.00 %" discount_price : "72.00" sgst : "0.00" cgst : "0.00" igst : "116.64" rounding_off : "0.64" grand_total : "764.00" amount_paid : "0.00" balance_due : "764.00" pick_up_options : "Delivery To Store" pick_up_priority : {"name":"Medium","color":"#4B82D6"} remarks : "check" status : {"status_id":"1","name":"Received","color":{"text":"#D9A003","background":"#FFFAE5"},"updated_at":""} created_at_date_time : {"date":"01 May, 2024","time":"02:59 PM"} drug_license : {"name":"License 21B","license_no":"8979DFJKFHSJKDHKSF5456"},{"name":"License 20B","license_no":"DAIOUF908908FSDFSDF"} total_item : "1" address : {"address_id":"69","name":"Sevak Medical","contact_no":"91 9887988979","address":"Survey No. - 3763 Plot No. - C Paiki Plot, Front Side, City, First Floor, No. - A, Vasta Devdi Rd, opp. Zenith Mill, Katargam, Surat, Gujarat 395004","country":{"id":"101","name":"India"},"state":{"id":"12","name":"Gujarat"},"city":{"id":"1041","name":"Surat"}}

Constructors

Order({UserDetails? userDetails, String? orderId, String? cnAmount, String? showInvoiceBtn, String? orderNumber, String? subTotal, String? discount, String? discountPrice, String? sgst, String? cgst, String? igst, String? roundingOff, String? grandTotal, String? amountPaid, String? balanceDue, String? pickUpOptions, PickUpPriority? pickUpPriority, String? remarks, Status? status, CreatedAtDateTime? createdAtDateTime, List<DrugLicense>? drugLicense, String? totalItem, PrescriptionImageObj? prescriptionImageObj, Address? address})
Order.fromJson(dynamic json)

Properties

address Address?
getter/setter pair
amountPaid String?
getter/setter pair
balanceDue String?
getter/setter pair
cgst String?
getter/setter pair
cnAmount String?
getter/setter pair
createdAtDateTime CreatedAtDateTime?
getter/setter pair
discount String?
getter/setter pair
discountPrice String?
getter/setter pair
drugLicense List<DrugLicense>?
getter/setter pair
grandTotal String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
igst String?
getter/setter pair
orderId String?
getter/setter pair
orderNumber String?
getter/setter pair
pickUpOptions String?
getter/setter pair
pickUpPriority PickUpPriority?
getter/setter pair
prescriptionImageObj PrescriptionImageObj?
getter/setter pair
remarks String?
getter/setter pair
roundingOff String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sgst String?
getter/setter pair
showInvoiceBtn String?
getter/setter pair
status Status?
getter/setter pair
subTotal String?
getter/setter pair
totalItem String?
getter/setter pair
userDetails UserDetails?
getter/setter pair

Methods

copyWith({UserDetails? userDetails, String? orderId, String? cnAmount, String? showInvoiceBtn, String? orderNumber, String? subTotal, String? discount, String? discountPrice, String? sgst, String? cgst, String? igst, String? roundingOff, String? grandTotal, String? amountPaid, String? balanceDue, String? pickUpOptions, PickUpPriority? pickUpPriority, String? remarks, Status? status, CreatedAtDateTime? createdAtDateTime, List<DrugLicense>? drugLicense, String? totalItem, Address? address, PrescriptionImageObj? prescriptionImageObj}) Order
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited