Countrylist class

Constructors

Countrylist({String? id, String? name, String? flag, String? phonecode})
Countrylist.fromJson(dynamic json)

Properties

flag String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
name String?
no setter
phonecode String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? name, String? flag, String? phonecode}) Countrylist
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited