TitleObj class

Constructors

TitleObj({String? name, String? color})
TitleObj.fromJson(dynamic json)

Properties

color String?
no setter
hashCode int
The hash code for this object.
no setterinherited
name String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? color}) TitleObj
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited