Cart class
quantity : "12" discount : "10.00" out_of_stock_1_as_out : "0" discount_price : "72.00" cart_id : "407" total_taxable_item_vise : "648.00" total_item_vise : "720.00" sgst : "0.00" cgst : "0.00" igst : "18" sgst_price : "0.00" cgst_price : "0.00" igst_price : "116.64" total_gst : "116.64"
Constructors
- Cart({String? schemeDiscount, String? schemeDiscountPrice, String? quantity, String? quantityFree, String? discountAsPerFixed, String? discountAsPerFixedPrice, String? productDiscount, String? productDiscountPrice, String? productDiscountSpecial, String? productDiscountSpecialPrice, String? appBannersId, String? appBannersParentId, String? productDiscountSpecialCompany, String? productDiscountSpecialCompanyPrice, String? outOfStock1AsOut, String? discount, String? discountPrice, String? cartId, String? totalTaxableItemVise, String? totalItemVise, String? sgst, String? cgst, String? igst, String? sgstPrice, String? cgstPrice, String? igstPrice, String? totalGst})
- Cart.fromJson(dynamic json)
Properties
- appBannersId → String?
-
no setter
- appBannersParentId → String?
-
no setter
- cartId → String?
-
no setter
- cgst → String?
-
no setter
- cgstPrice → String?
-
no setter
- discount → String?
-
no setter
- discountAsPerFixed → String?
-
no setter
- discountAsPerFixedPrice → String?
-
no setter
- discountPrice → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- igst → String?
-
no setter
- igstPrice → String?
-
no setter
- outOfStock1AsOut → String?
-
no setter
- productDiscount → String?
-
no setter
- productDiscountPrice → String?
-
no setter
- productDiscountSpecial → String?
-
no setter
- productDiscountSpecialCompany → String?
-
no setter
- productDiscountSpecialCompanyPrice → String?
-
no setter
- productDiscountSpecialPrice → String?
-
no setter
- quantity → String?
-
no setter
- quantityFree → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemeDiscount → String?
-
no setter
- schemeDiscountPrice → String?
-
no setter
- sgst → String?
-
no setter
- sgstPrice → String?
-
no setter
- totalGst → String?
-
no setter
- totalItemVise → String?
-
no setter
- totalTaxableItemVise → String?
-
no setter
Methods
-
copyWith(
{String? schemeDiscount, String? schemeDiscountPrice, String? quantity, String? quantityFree, String? discountAsPerFixed, String? discountAsPerFixedPrice, String? productDiscount, String? productDiscountPrice, String? productDiscountSpecial, String? productDiscountSpecialPrice, String? appBannersId, String? appBannersParentId, String? productDiscountSpecialCompany, String? productDiscountSpecialCompanyPrice, String? outOfStock1AsOut, String? discount, String? discountPrice, String? cartId, String? totalTaxableItemVise, String? totalItemVise, String? sgst, String? cgst, String? igst, String? sgstPrice, String? cgstPrice, String? igstPrice, String? totalGst}) → Cart -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited