FreeProductTotal class

sub_total : "120.00"

Constructors

FreeProductTotal({String? subTotal})
FreeProductTotal.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTotal String?
getter/setter pair

Methods

copyWith({String? subTotal}) FreeProductTotal
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited