RemoveColumnItem class
Constructors
- RemoveColumnItem({String? gst, String? schemeDiscount})
- RemoveColumnItem.fromJson(dynamic json)
Properties
- gst → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemeDiscount → String?
-
no setter
Methods
-
copyWith(
{String? gst, String? schemeDiscount}) → RemoveColumnItem -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited