ShowQuantity class

quantity : "" indicator : ""

Constructors

ShowQuantity({String? quantity, String? indicator})
ShowQuantity.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
indicator String?
getter/setter pair
quantity String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? quantity, String? indicator}) ShowQuantity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited