Summary class

taxable : "648.00" sgst : "0.00" cgst : "0.00" igst : "18" sgst_price : "0.00" cgst_price : "0.00" igst_price : "116.64"

Constructors

Summary({String? sgstShow, String? igstShow, String? taxable, String? sgst, String? cgst, String? igst, String? sgstPrice, String? cgstPrice, String? igstPrice})
Summary.fromJson(dynamic json)

Properties

cgst String?
getter/setter pair
cgstPrice String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
igst String?
getter/setter pair
igstPrice String?
getter/setter pair
igstShow String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sgst String?
getter/setter pair
sgstPrice String?
getter/setter pair
sgstShow String?
getter/setter pair
taxable String?
getter/setter pair

Methods

copyWith({String? taxable, String? sgst, String? cgst, String? igst, String? sgstPrice, String? cgstPrice, String? igstPrice, String? sgstShow, String? igstShow}) Summary
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited