UserWiseChanges class
Constructors
- UserWiseChanges({ChangeTaxableToAmount? changeTaxableToAmount, String? removeCnDnBtn, RemoveColumnItem? removeColumnItem})
- UserWiseChanges.fromJson(dynamic json)
Properties
- changeTaxableToAmount → ChangeTaxableToAmount?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- removeCnDnBtn → String?
-
no setter
- removeColumnItem → RemoveColumnItem?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChangeTaxableToAmount? changeTaxableToAmount, String? removeCnDnBtn, RemoveColumnItem? removeColumnItem}) → UserWiseChanges -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited