DiscountArray class

Constructors

DiscountArray({String? name, String? price, String? inAdmin})
DiscountArray.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
inAdmin String?
no setter
name String?
no setter
price String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? price, String? inAdmin}) DiscountArray
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited