menu
pharma_hub_365 package
documentation
pages/credit_note/CreditNoteCartReposne.dart
Division class
Division class
dark_mode
light_mode
Division
class
Constructors
Division
({
String
?
id
,
String
?
name
})
Division.fromJson
(
dynamic
json
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
id
→
String
?
no setter
name
→
String
?
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
String
?
id
,
String
?
name
})
→
Division
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
pharma_hub_365 package
documentation
pages/credit_note/CreditNoteCartReposne
Division class
CreditNoteCartReposne library