NotificationsItems class
Constructors
- NotificationsItems({String? notificationId, String? idRedirect, String? contentType, String? title, String? message, String? image, String? deviceType, CreatedAtDateTime? createdAtDateTime})
- NotificationsItems.fromJson(dynamic json)
Properties
- contentType → String?
-
no setter
- createdAtDateTime → CreatedAtDateTime?
-
no setter
- deviceType → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- idRedirect → String?
-
no setter
- image → String?
-
no setter
- message → String?
-
no setter
- notificationId → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
no setter
Methods
-
copyWith(
{String? notificationId, String? idRedirect, String? contentType, String? title, String? message, String? image, String? deviceType, CreatedAtDateTime? createdAtDateTime}) → NotificationsItems -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited