RemoveColumn class
Constructors
- RemoveColumn({String? taxable, String? gst, String? schemeDiscount, String? expiredDiscount})
- RemoveColumn.fromJson(dynamic json)
Properties
- expiredDiscount → String?
-
no setter
- gst → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemeDiscount → String?
-
no setter
- taxable → String?
-
no setter
Methods
-
copyWith(
{String? taxable, String? gst, String? schemeDiscount, String? expiredDiscount}) → RemoveColumn -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited