Status class
status_id : "1" name : "Received" color : {"text":"#D9A003","background":"#FFFAE5"} updated_at : ""
Constructors
Properties
- color ↔ ApiColor?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusId ↔ String?
-
getter/setter pair
- updatedAt ↔ String?
-
getter/setter pair
Methods
-
copyWith(
{String? statusId, String? name, ApiColor? color, String? updatedAt}) → Status -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited