StatusArray class
status : "Received" notes : "" created_at_date_time : {"date":"01 May, 2024","time":"02:59 PM"}
Constructors
- StatusArray({String? status, String? notes, CreatedAtDateTime? createdAtDateTime})
- StatusArray.fromJson(dynamic json)
Properties
- createdAtDateTime ↔ CreatedAtDateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- notes ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
Methods
-
copyWith(
{String? status, String? notes, CreatedAtDateTime? createdAtDateTime}) → StatusArray -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited