MenuArray class
Constructors
Properties
- bgColor → String?
-
no setter
- countObj → CountObj?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconCrop → String?
-
no setter
- iconFull → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleObj → TitleObj?
-
no setter
- type → String?
-
no setter
Methods
-
copyWith(
{String? type, TitleObj? titleObj, CountObj? countObj, String? bgColor, String? iconFull, String? iconCrop}) → MenuArray -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited