menu
pharma_hub_365 package
documentation
model/other/DashboardCountResponse.dart
TitleObj class
TitleObj class
dark_mode
light_mode
TitleObj
class
Constructors
TitleObj
({
String
?
name
,
String
?
color
})
TitleObj.fromJson
(
dynamic
json
)
Properties
color
→
String
?
no setter
hashCode
→
int
The hash code for this object.
no setter
inherited
name
→
String
?
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
String
?
name
,
String
?
color
})
→
TitleObj
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
pharma_hub_365 package
documentation
model/other/DashboardCountResponse
TitleObj class
DashboardCountResponse library