Product class
product_id : "66"
category : {"id":"8","name":"ANTI-INFECTIVE RANGE"}
manufacture : {"id":"5","name":"Believe Wellness"}
marketed_by : {"id":"1","name":"Believe"}
company : {"id":"1","name":"Believe Wellness"}
division : {"id":"","name":""}
name : ""
brand : "CEFOWELL-200 TAB"
composition : "Cefpodoxime 200mg"
units_per_package : "10"
per_unit_quantity : "10"
packaging_display : "10 X 10 TABLET"
quantity : "306"
show_quantity : {"quantity":"","indicator":""}
return_quantity : ""
color : {"text":"#007405","background":"#D8FFD9"}
min_purchase_qty : "1"
max_purchase_qty : "306"
mrp : "210.00"
price_to_show : {"key":"PTR","value":"60.00"}
discount : "10.00"
gst : "18"
batch_no : "BN005"
manufacturing_date : "01 Jan, 2024"
expiry_date : "28 Jun, 2024"
barcode : ""
scheme : "10 + 2"
scheme_min_purchase : "10"
scheme_provide : "2"
dosage_strength : ""
dosage_form : "TABLET"
packaging_type : ""
description : ""
storage_conditions : ""
master_user_id : "2"
Constructors
-
Product({String? productId, Category? category, ColorApi? color, Manufacture? manufacture, MarketedBy? marketedBy, Company? company, Division? division, String? name, String? brand, String? composition, String? unitsPerPackage, String? perUnitQuantity, String? packagingDisplay, String? quantity, ShowQuantity? showQuantity, String? returnQuantity, String? minPurchaseQty, String? maxPurchaseQty, String? mrp, List<
PriceToShow> ? priceToShow, String? discount, String? gst, String? batchNo, String? manufacturingDate, String? expiryDate, String? barcode, String? scheme, String? schemeMinPurchase, String? schemeProvide, String? dosageStrength, String? dosageForm, String? packagingType, String? description, String? storageConditions, String? masterUserId}) - Product.fromJson(dynamic json)
Properties
- barcode ↔ String?
-
getter/setter pair
- batchNo ↔ String?
-
getter/setter pair
- brand ↔ String?
-
getter/setter pair
- category ↔ Category?
-
getter/setter pair
- color ↔ ColorApi?
-
getter/setter pair
- company ↔ Company?
-
getter/setter pair
- composition ↔ String?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- discount ↔ String?
-
getter/setter pair
- division ↔ Division?
-
getter/setter pair
- dosageForm ↔ String?
-
getter/setter pair
- dosageStrength ↔ String?
-
getter/setter pair
- expiryDate ↔ String?
-
getter/setter pair
- gst ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- manufacture ↔ Manufacture?
-
getter/setter pair
- manufacturingDate ↔ String?
-
getter/setter pair
- marketedBy ↔ MarketedBy?
-
getter/setter pair
- masterUserId ↔ String?
-
getter/setter pair
- maxPurchaseQty ↔ String?
-
getter/setter pair
- minPurchaseQty ↔ String?
-
getter/setter pair
- mrp ↔ String?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- packagingDisplay ↔ String?
-
getter/setter pair
- packagingType ↔ String?
-
getter/setter pair
- perUnitQuantity ↔ String?
-
getter/setter pair
-
priceToShow
↔ List<
PriceToShow> ? -
getter/setter pair
- productId ↔ String?
-
getter/setter pair
- quantity ↔ String?
-
getter/setter pair
- returnQuantity ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme ↔ String?
-
getter/setter pair
- schemeMinPurchase ↔ String?
-
getter/setter pair
- schemeProvide ↔ String?
-
getter/setter pair
- showQuantity ↔ ShowQuantity?
-
getter/setter pair
- storageConditions ↔ String?
-
getter/setter pair
- unitsPerPackage ↔ String?
-
getter/setter pair
Methods
-
copyWith(
{String? productId, Category? category, ColorApi? color, Manufacture? manufacture, MarketedBy? marketedBy, Company? company, Division? division, String? name, String? brand, String? composition, String? unitsPerPackage, String? perUnitQuantity, String? packagingDisplay, String? quantity, ShowQuantity? showQuantity, String? returnQuantity, String? minPurchaseQty, String? maxPurchaseQty, String? mrp, List< PriceToShow> ? priceToShow, String? discount, String? gst, String? batchNo, String? manufacturingDate, String? expiryDate, String? barcode, String? scheme, String? schemeMinPurchase, String? schemeProvide, String? dosageStrength, String? dosageForm, String? packagingType, String? description, String? storageConditions, String? masterUserId}) → Product -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited