Cart class
Constructors
- Cart({String? totalQuantity, String? extraClaimProduct, String? schemeDiscount, String? schemeDiscountPrice, String? price, String? quantity, String? quantityFree, String? productDiscountSpecial, String? productDiscountSpecialPrice, String? productDiscountSpecialCompany, String? productDiscountSpecialCompanyPrice, String? discountAsPerFixed, String? discountAsPerFixedPrice, String? extraDiscountAsPerFixed, String? extraDiscountAsPerFixedPrice, String? productDiscount, String? productDiscountPrice, String? outOfStock1AsOut, String? totalDiscount, String? totalDiscountWithFreeScheme, String? cnCartId, String? totalTaxableItemVise, String? totalItemVise, String? sgst, String? cgst, String? igst, String? sgstPrice, String? cgstPrice, String? igstPrice, String? totalGst})
- Cart.fromJson(dynamic json)
Properties
- cgst → String?
-
no setter
- cgstPrice → String?
-
no setter
- cnCartId → String?
-
no setter
- discountAsPerFixed → String?
-
no setter
- discountAsPerFixedPrice → String?
-
no setter
- extraClaimProduct → String?
-
no setter
- extraDiscountAsPerFixed → String?
-
no setter
- extraDiscountAsPerFixedPrice → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- igst → String?
-
no setter
- igstPrice → String?
-
no setter
- outOfStock1AsOut → String?
-
no setter
- price → String?
-
no setter
- productDiscount → String?
-
no setter
- productDiscountPrice → String?
-
no setter
- productDiscountSpecial → String?
-
no setter
- productDiscountSpecialCompany → String?
-
no setter
- productDiscountSpecialCompanyPrice → String?
-
no setter
- productDiscountSpecialPrice → String?
-
no setter
- quantity → String?
-
no setter
- quantityFree → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemeDiscount → String?
-
no setter
- schemeDiscountPrice → String?
-
no setter
- sgst → String?
-
no setter
- sgstPrice → String?
-
no setter
- totalDiscount → String?
-
no setter
- totalDiscountWithFreeScheme → String?
-
no setter
- totalGst → String?
-
no setter
- totalItemVise → String?
-
no setter
- totalQuantity → String?
-
no setter
- totalTaxableItemVise → String?
-
no setter
Methods
-
copyWith(
{String? totalQuantity, String? extraClaimProduct, String? schemeDiscount, String? schemeDiscountPrice, String? price, String? quantity, String? quantityFree, String? productDiscountSpecial, String? productDiscountSpecialPrice, String? productDiscountSpecialCompany, String? productDiscountSpecialCompanyPrice, String? discountAsPerFixed, String? discountAsPerFixedPrice, String? extraDiscountAsPerFixed, String? extraDiscountAsPerFixedPrice, String? productDiscount, String? productDiscountPrice, String? outOfStock1AsOut, String? totalDiscount, String? totalDiscountWithFreeScheme, String? cnCartId, String? totalTaxableItemVise, String? totalItemVise, String? sgst, String? cgst, String? igst, String? sgstPrice, String? cgstPrice, String? igstPrice, String? totalGst}) → Cart -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited