CreditNoteCartReposne class

Constructors

CreditNoteCartReposne({List<CreditNoteData>? data, String? summaryAdd, RemoveColumn? removeColumn, String? intraState1InterState2, String? totalItem, String? subTotal, List<DiscountArray>? discountArray, String? schemeDiscountPrice, String? cashDiscount, String? cashDiscountPrice, String? productDiscountPrice, String? productDiscountSpecialPrice, String? productDiscountSpecialCompanyPrice, String? extraDiscountAsPerFixed, String? extraDiscountAsPerFixedPrice, String? discountPrice, String? sgst, String? cgst, String? igst, String? tcsPer, String? tcs, String? freight, String? roundingOff, String? grandTotal, num? totalRecords, List<CreditNoteSummary>? summary, num? success, String? message})
CreditNoteCartReposne.fromJson(dynamic json)

Properties

cashDiscount String?
no setter
cashDiscountPrice String?
no setter
cgst String?
no setter
data List<CreditNoteData>?
no setter
discountArray List<DiscountArray>?
no setter
discountPrice String?
no setter
extraDiscountAsPerFixed String?
no setter
extraDiscountAsPerFixedPrice String?
no setter
freight String?
no setter
grandTotal String?
no setter
hashCode int
The hash code for this object.
no setterinherited
igst String?
no setter
intraState1InterState2 String?
no setter
message String?
no setter
productDiscountPrice String?
no setter
productDiscountSpecialCompanyPrice String?
no setter
productDiscountSpecialPrice String?
no setter
removeColumn RemoveColumn?
no setter
roundingOff String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemeDiscountPrice String?
no setter
sgst String?
no setter
subTotal String?
no setter
success num?
no setter
summary List<CreditNoteSummary>?
no setter
summaryAdd String?
no setter
tcs String?
no setter
tcsPer String?
no setter
totalItem String?
no setter
totalRecords num?
no setter

Methods

copyWith({List<CreditNoteData>? data, String? summaryAdd, RemoveColumn? removeColumn, String? intraState1InterState2, String? totalItem, String? subTotal, List<DiscountArray>? discountArray, String? schemeDiscountPrice, String? cashDiscount, String? cashDiscountPrice, String? productDiscountPrice, String? productDiscountSpecialPrice, String? productDiscountSpecialCompanyPrice, String? extraDiscountAsPerFixed, String? extraDiscountAsPerFixedPrice, String? discountPrice, String? sgst, String? cgst, String? igst, String? tcsPer, String? tcs, String? freight, String? roundingOff, String? grandTotal, num? totalRecords, List<CreditNoteSummary>? summary, num? success, String? message}) CreditNoteCartReposne
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited