CreditNoteSummary class
Constructors
Properties
- cgst → String?
-
no setter
- cgstPrice → String?
-
no setter
- gst → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- igst → String?
-
no setter
- igstPrice → String?
-
no setter
- igstShow → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sgst → String?
-
no setter
- sgstPrice → String?
-
no setter
- sgstShow → String?
-
no setter
- taxable → String?
-
no setter
Methods
-
copyWith(
{String? gst, String? taxable, String? sgst, String? sgstShow, String? cgst, String? igst, String? igstShow, String? sgstPrice, String? cgstPrice, String? igstPrice}) → CreditNoteSummary -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited